@@ -56,8 +56,8 @@ import typing as t
 class GunicornHelper:
     @staticmethod
     def force_cfg(cfg: t.Dict["str", t.Any]) -> None:
-        cfg["production"] = True
-        cfg["debug"] = False
+        cfg["server"]["production"] = True
+        cfg["server"]["debug"] = False
         return cfg
 
     @staticmethod
